@@ -61,11 +61,11 @@ class account_move_line(osv.osv):
             else:
                 journal_id = context['journal_id']
                 period_id = context['period_id']
-            journal=self.pool.get('account.journal').browse(cr,uid,[journal_id])[0]
+            journal = self.pool.get('account.journal').browse(cr,uid,[journal_id])[0]
             if not journal.allow_date:
                 period=self.pool.get('account.period').browse(cr,uid,[period_id])[0]
 
-                date = time.strptime(vals['date'], '%Y-%m-%d')
+                date = time.strptime(vals['date'][:10], '%Y-%m-%d')
                 if not (date >= time.strptime(period.date_start,'%Y-%m-%d')
                         and date <= time.strptime(period.date_stop,'%Y-%m-%d') ):
 
