@@ -50,7 +50,7 @@ class report_rappel(report_sxw.rml_parse):
         res_partner = pooler.get_pool(self.cr.dbname).get('res.partner')
         res_partner_address = pooler.get_pool(self.cr.dbname).get('res.partner.address')
         adr = res_partner.address_get(self.cr, self.uid, [partner.id], [type])[type]
-        return adr and res_partner_address.read(self.cr, self.uid, [adr]) or False
+        return adr and res_partner_address.read(self.cr, self.uid, [adr]) or [{}]
 
     def _lines_get(self, partner):
         moveline_obj = pooler.get_pool(self.cr.dbname).get('account.move.line')
