@@ -65,21 +65,27 @@ class ir_translation(osv.osv):
 
     def _auto_init(self, cr, context={}):
         super(ir_translation, self)._auto_init(cr, context)
+        #Delete the existing indexes in the system if any.
         cr.execute('SELECT indexname FROM pg_indexes WHERE indexname = %s', ('ir_translation_ltns',))
-        if not cr.fetchone():
-            cr.execute('CREATE INDEX ir_translation_ltns ON ir_translation (lang, type, name, src)')
+        if cr.fetchone():
+            cr.execute('DROP INDEX ir_translation_ltns')
             cr.commit()
-
+        
+        cr.execute('SELECT indexname FROM pg_indexes WHERE indexname = %s', ('ir_translation_lts',))
+        if cr.fetchone():
+            cr.execute('DROP INDEX ir_translation_lts')
+            cr.commit()
+            
         cr.execute('SELECT indexname FROM pg_indexes WHERE indexname = %s', ('ir_translation_ltn',))
         if not cr.fetchone():
-            cr.execute('CREATE INDEX ir_translation_ltn ON ir_translation (lang, type, name)')
+            cr.execute('CREATE INDEX ir_translation_ltn ON ir_translation (name, lang, type)')
             cr.commit()
-
-        cr.execute('SELECT indexname FROM pg_indexes WHERE indexname = %s', ('ir_translation_lts',))
+        # There is a size limit on btree indexed values so we can't index src column with normal btree.
+        cr.execute('SELECT indexname FROM pg_indexes WHERE indexname = %s', ('ir_translation_src_hash_idx',))
         if not cr.fetchone():
-            cr.execute('CREATE INDEX ir_translation_lts ON ir_translation (lang, type, src)')
+            cr.execute('CREATE INDEX ir_translation_src_hash_idx ON ir_translation using hash (src)')
             cr.commit()
-
+            
     @tools.cache(skiparg=3, multi='ids')
     def _get_ids(self, cr, uid, name, tt, lang, ids):
         translations = dict.fromkeys(ids, False)
@@ -123,9 +129,20 @@ class ir_translation(osv.osv):
 
     @tools.cache(skiparg=3)
     def _get_source(self, cr, uid, name, tt, lang, source=None):
+        """
+        Returns the translation for the given combination of name, type, language
+        and source. All values passed to this method should be unicode (not byte strings),
+        especially ``source``.
+
+        :param name: identification of the term to translate, such as field name
+        :param type: type of term to translate (see ``type`` field on ir.translation)
+        :param lang: language code of the desired translation
+        :param source: optional source term to translate (should be unicode)
+        :rtype: unicode
+        :return: the request translation, or an empty unicode string if no translation was
+                 found and `source` was not passed
+        """
         if source:
-            #if isinstance(source, unicode):
-            #   source = source.encode('utf8')
             cr.execute('select value ' \
                     'from ir_translation ' \
                     'where lang=%s ' \
@@ -141,9 +158,9 @@ class ir_translation(osv.osv):
                         'and name=%s',
                     (lang or '', tt, tools.ustr(name)))
         res = cr.fetchone()
-        trad = res and res[0] or ''
+        trad = res and res[0] or u''
         if source and not trad:
-            return source
+            return tools.ustr(source)
         return trad
 
     def create(self, cursor, user, vals, context=None):
