@@ -100,7 +100,7 @@ class res_partner_title(osv.osv):
     _name = 'res.partner.title'
     _columns = {
         'name': fields.char('Title', required=True, size=46, translate=True),
-        'shortcut': fields.char('Shortcut', required=True, size=16),
+        'shortcut': fields.char('Shortcut', required=True, size=16, translate=True),
         'domain': fields.selection([('partner','Partner'),('contact','Contact')], 'Domain', required=True, size=24)
     }
     _order = 'name'
