@@ -65,7 +65,7 @@ class hr_analytic_timesheet(osv.osv):
         emp_obj = self.pool.get('hr.employee')
         emp_id = emp_obj.search(cr, uid, [('user_id', '=', context.get('user_id', uid))])
         if emp_id:
-            emp=emp_obj.browse(cr, uid, emp_id[0], context)
+            emp = emp_obj.browse(cr, uid, emp_id[0], context)
             if emp.product_id:
                 return emp.product_id.id
         return False
@@ -74,7 +74,7 @@ class hr_analytic_timesheet(osv.osv):
         emp_obj = self.pool.get('hr.employee')
         emp_id = emp_obj.search(cr, uid, [('user_id', '=', context.get('user_id', uid))])
         if emp_id:
-            emp=emp_obj.browse(cr, uid, emp_id[0], context)
+            emp = emp_obj.browse(cr, uid, emp_id[0], context)
             if emp.product_id:
                 return emp.product_id.uom_id.id
         return False
@@ -85,7 +85,7 @@ class hr_analytic_timesheet(osv.osv):
         if emp_id:
             emp = self.pool.get('hr.employee').browse(cr, uid, emp_id[0], context=context)
             if bool(emp.product_id):
-                a =  emp.product_id.product_tmpl_id.property_account_expense.id
+                a = emp.product_id.product_tmpl_id.property_account_expense.id
                 if not a:
                     a = emp.product_id.categ_id.property_account_expense_categ.id
                 if a:
@@ -138,11 +138,12 @@ class hr_analytic_timesheet(osv.osv):
     def on_change_user_id(self, cr, uid, ids, user_id):
         if not user_id:
             return {}
+        context = {'user_id': user_id}
         return {'value' : {
-            'product_id' : self._getEmployeeProduct(cr,user_id, context= {}),
-            'product_uom_id' : self._getEmployeeUnit(cr, user_id, context= {}),
-            'general_account_id' :self. _getGeneralAccount(cr, user_id, context= {}),
-            'journal_id' : self._getAnalyticJournal(cr, user_id, context= {}),
+            'product_id' : self._getEmployeeProduct(cr, uid, context),
+            'product_uom_id' : self._getEmployeeUnit(cr, uid, context),
+            'general_account_id' :self._getGeneralAccount(cr, uid, context),
+            'journal_id' : self._getAnalyticJournal(cr, uid, context),
         }}
 hr_analytic_timesheet()
 
