@@ -300,7 +300,7 @@ class mrp_repair(osv.osv):
                             name = operation.name
                         
                         if operation.product_id.property_account_income:
-                            account_id = operation.product_id.property_account_income
+                            account_id = operation.product_id.property_account_income.id
                         elif operation.product_id.categ_id.property_account_income_categ:
                             account_id = operation.product_id.categ_id.property_account_income_categ.id
                         else:
@@ -328,7 +328,7 @@ class mrp_repair(osv.osv):
                         if not fee.product_id:
                             raise osv.except_osv(_('Warning !'), _('No product defined on Fees!'))
                         if fee.product_id.property_account_income:
-                            account_id = fee.product_id.property_account_income
+                            account_id = fee.product_id.property_account_income.id
                         elif fee.product_id.categ_id.property_account_income_categ:
                             account_id = fee.product_id.categ_id.property_account_income_categ.id
                         else:
