@@ -515,7 +515,8 @@ class pos_order(osv.osv):
                 'reference': order.name,
                 'partner_id': order.partner_id.id,
                 'comment': order.note or '',
-                'price_type': 'tax_included'
+                'price_type': 'tax_included',
+                'journal_id': order.sale_journal.id
             }
             inv.update(inv_ref.onchange_partner_id(cr, uid, [], 'out_invoice', order.partner_id.id)['value'])
 
