@@ -258,6 +258,7 @@ class task(osv.osv):
     def copy_data(self, cr, uid, id, default={},context={}):
         default = default or {}
         default['work_ids'] = []
+        default['remaining_hours'] = float(self.read(cr, uid, id, ['planned_hours'])['planned_hours'])
         return super(task, self).copy_data(cr, uid, id, default, context)
 
     _columns = {
@@ -302,6 +303,19 @@ class task(osv.osv):
     }
     _order = "sequence, priority, date_deadline, id"
 
+    def _check_recursion(self, cr, uid, ids):
+        level = 100
+        while len(ids):
+            cr.execute('select distinct parent_id from project_task where id in %s', (tuple(ids),))
+            ids = filter(None, map(lambda x:x[0], cr.fetchall()))
+            if not level:
+                return False
+            level -= 1
+        return True
+
+    _constraints = [
+        (_check_recursion, _('Error ! You cannot create recursive tasks.'), ['parent_id'])
+    ]
     #
     # Override view according to the company definition
     #
