@@ -65,27 +65,30 @@ def _create_returns(self, cr, uid, data, context):
     pick_obj = pool.get('stock.picking')
     uom_obj = pool.get('product.uom')
 
-    pick=pick_obj.browse(cr, uid, [data['id']])[0]
-    new_picking=None
-    date_cur=time.strftime('%Y-%m-%d %H:%M:%S')
+    pick = pick_obj.browse(cr, uid, [data['id']])[0]
+    new_picking = None
+    date_cur = time.strftime('%Y-%m-%d %H:%M:%S')
 
     for move in move_obj.browse(cr, uid, data['form'].get('returns',[])):
+        move_qty = data['form']['return%s' % move.id]
+        if (not move_qty) or (move_qty <= 0.0):
+            continue
         if not new_picking:
-            if pick.type=='out':
+            if pick.type in ['out','delivery']:
                 new_type='in'
             elif pick.type=='in':
                 new_type='out'
             else:
                 new_type='internal'
-            new_picking=pick_obj.copy(cr, uid, pick.id, {'name':'%s (return)' % pick.name,
+            new_picking = pick_obj.copy(cr, uid, pick.id, {'name':'%s (return)' % pick.name,
                     'move_lines':[], 'state':'draft', 'type':new_type, 
                     'date':date_cur, 'invoice_state':data['form']['invoice_state'],})
-        new_location=move.location_dest_id.id
+        new_location = move.location_dest_id.id
 
-        new_move=move_obj.copy(cr, uid, move.id, {
-            'product_qty': data['form']['return%s' % move.id],
+        new_move = move_obj.copy(cr, uid, move.id, {
+            'product_qty': move_qty,
             'product_uos_qty': uom_obj._compute_qty(cr, uid, move.product_uom.id,
-                data['form']['return%s' % move.id], move.product_uos.id),
+                move_qty, move.product_uos.id),
             'picking_id':new_picking, 'state':'draft',
             'location_id':new_location, 'location_dest_id':move.location_id.id,
             'date':date_cur, 'date_planned':date_cur,})
@@ -94,6 +97,8 @@ def _create_returns(self, cr, uid, data, context):
         if new_picking:
             wf_service.trg_validate(uid, 'stock.picking', new_picking, 'button_confirm', cr)
         pick_obj.force_assign(cr, uid, [new_picking], context)
+    else:
+        raise wizard.except_wizard(_('Warning !'), _('You cannot return a packing with a product quantity zero or less!'))
     return new_picking
 
 def _action_open_window(self, cr, uid, data, context):
