@@ -424,7 +424,8 @@ class one2many(_column):
             res[id] = []
         ids2 = obj.pool.get(self._obj).search(cr, user, [(self._fields_id, 'in', ids)], limit=self._limit, context=context)
         for r in obj.pool.get(self._obj)._read_flat(cr, user, ids2, [self._fields_id], context=context, load='_classic_write'):
-            res[r[self._fields_id]].append(r['id'])
+            if r[self._fields_id] in res:
+                res[r[self._fields_id]].append(r['id'])
         return res
 
     def set(self, cr, obj, id, field, values, user=None, context=None):
@@ -862,9 +863,10 @@ class property(function):
             default_val = (d and int(d.split(',')[1])) or False
 
         vids = [obj._name + ',' + str(id) for id in  ids]
-        nids = property.search(cr, uid, [('fields_id', '=', definition_id),
-            ('res_id', 'in', vids)])
-
+        dom = [('fields_id', '=', definition_id)]
+        if vids:
+            dom += [('res_id', 'in', vids)]
+        nids = property.search(cr, uid, dom)
         res = {}
         for id in ids:
             res[id] = default_val
