@@ -1,10 +1,9 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
-##############################################################################
 #
 #    OpenERP, Open Source Management Solution	
 #    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
-#    $Id$
+#    Copyright (C) 2004-TODAY OpenERP S.A. (<http://www.openerp.com>). All Rights Reserved
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,29 +18,27 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-##############################################################################
 
 name = 'openerp-server'
-version = '5.0.14'
+version = '5.0.15'
 major_version = '5.0'
 description = 'OpenERP Server'
-long_desc = '''\
-OpenERP is a complete ERP and CRM. The main features are accounting (analytic
+long_desc = '''OpenERP is a complete ERP and CRM. The main features are accounting (analytic
 and financial), stock management, sales and purchases management, tasks
 automation, marketing campaigns, help desk, POS, etc. Technical features include
 a distributed server, flexible workflows, an object database, a dynamic GUI,
 customizable reports, and XML-RPC interfaces.
 '''
-classifiers = """\
-Development Status :: 5 - Production/Stable
+classifiers = """Development Status :: 5 - Production/Stable
 License :: OSI Approved :: GNU General Public License (GPL)
 Programming Language :: Python
 """
 url = 'http://www.openerp.com'
-author = 'Tiny.be'
-author_email = 'info@tiny.be'
+author = 'OpenERP S.A.'
+author_email = 'info@openerp.com'
 support_email = 'support@openerp.com'
 license = 'GPL-3'
+download_url='http://www.openerp.com/download/stable/source/openerp-server-5.0.15.tar.gz'
 
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
 
