@@ -1,7 +1,7 @@
 # -*- encoding: utf-8 -*-
 ##############################################################################
 #
-#    OpenERP, Open Source Management Solution	
+#    OpenERP, Open Source Management Solution    
 #    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
 #    $Id$
 #
@@ -74,7 +74,7 @@ class report_custom(report_int):
             for cond in conditions:
                 if cond and cond[0]:
                     c = cond[0]
-                    temp = c[0](eval('obj.'+c[1]))
+                    temp = c[0](eval('obj.'+c[1],{},{'obj' : obj}))
                     if not eval('\''+temp+'\''+' '+c[2]+' '+'\''+str(c[3])+'\''):
                         tobreak = True
             if tobreak:
@@ -88,7 +88,7 @@ class report_custom(report_int):
                         row_canvas[i]=False
                 elif len(fields[i])==1:
                     if not isinstance(obj, browse_null):
-                        row.append(str(eval('obj.'+fields[i][0])))
+                        row.append(str(eval('obj.'+fields[i][0],{},{'obj' : obj})))
                     else:
                         row.append(None)
                 else:
@@ -108,7 +108,7 @@ class report_custom(report_int):
                 else:
                     key = levels.keys()
                 for l in key:
-                    objs = eval('obj.'+l)
+                    objs = eval('obj.'+l,{},{'obj' : obj})
                     if not isinstance(objs, browse_record_list) and type(objs) <> type([]):
                         objs = [objs]
                     field_new = []
@@ -193,7 +193,7 @@ class report_custom(report_int):
             def build_tree(obj, level, depth):
                 res = self._row_get(cr, uid,[obj], new_fields, new_cond)
                 level.append(depth)
-                new_obj = eval('obj.'+report['field_parent'][1])
+                new_obj = eval('obj.'+report['field_parent'][1],{},{'obj' : obj})
                 if not isinstance(new_obj, list) :
                     new_obj = [new_obj]
                 for o in  new_obj:
