@@ -172,7 +172,7 @@ def attr_get(node, attrs, dict={}):
     for key in dict:
         if node.get(key):
             if dict[key]=='str':
-                res[key] = str(node.get(key))
+                res[key] = tools.ustr(node.get(key))
             elif dict[key]=='bool':
                 res[key] = bool_get(node.get(key))
             elif dict[key]=='int':
