@@ -37,6 +37,9 @@ import logging
 import sys
 import pickle
 
+unsafe_eval = eval
+
+from tools.safe_eval import safe_eval as eval 
 
 class ConvertError(Exception):
     def __init__(self, doc, orig_excpt):
@@ -64,7 +67,7 @@ def _eval_xml(self,node, pool, cr, uid, idref, context=None):
                 f_use = node.get("use",'id').encode('ascii')
                 f_name = node.get("name",'').encode('utf-8')
 
-                q = eval(f_search, idref)
+                q = unsafe_eval(f_search, idref)
                 ids = pool.get(f_model).search(cr, uid, q)
                 if f_use != 'id':
                     ids = map(lambda x: x[f_use], pool.get(f_model).read(cr, uid, ids, [f_use]))
@@ -98,7 +101,7 @@ def _eval_xml(self,node, pool, cr, uid, idref, context=None):
                         all_timezones=[]
                     pytz=pytzclass()
                 idref2['pytz'] = pytz
-                return eval(a_eval, idref2)
+                return unsafe_eval(a_eval, idref2)
             if t == 'xml':
                 def _process(s, idref):
                     m = re.findall('[^%]%\((.*?)\)[ds]', s)
@@ -142,7 +145,7 @@ def _eval_xml(self,node, pool, cr, uid, idref, context=None):
         a_eval = node.get('eval','')
         if a_eval:
             idref['ref'] = lambda x: self.id_get(cr, False, x)
-            args = eval(a_eval, idref)
+            args = unsafe_eval(a_eval, idref)
         for n in node:
             return_val = _eval_xml(self,n, pool, cr, uid, idref, context)
             if return_val is not None:
@@ -204,13 +207,13 @@ class xml_import(object):
     def get_context(self, data_node, node, eval_dict):
         data_node_context = (len(data_node) and data_node.get('context','').encode('utf8'))
         if data_node_context:
-            context = eval(data_node_context, eval_dict)
+            context = unsafe_eval(data_node_context, eval_dict)
         else:
             context = {}
 
         node_context = node.get("context",'').encode('utf8')
         if node_context:
-            context.update(eval(node_context, eval_dict))
+            context.update(unsafe_eval(node_context, eval_dict))
 
         return context
 
@@ -240,7 +243,7 @@ form: module.record_id""" % (xml_id,)
         d_id = rec.get("id",'')
         ids = []
         if d_search:
-            ids = self.pool.get(d_model).search(cr,self.uid,eval(d_search))
+            ids = self.pool.get(d_model).search(cr,self.uid, unsafe_eval(d_search))
         if d_id:
             try:
                 ids.append(self.id_get(cr, d_model, d_id))
@@ -397,8 +400,8 @@ form: module.record_id""" % (xml_id,)
 
         def ref(str_id):
             return self.id_get(cr, None, str_id)
-        context=eval(context)
-        #domain=eval(domain) # XXX need to test this line -> uid, active_id, active_ids, ...
+        context=eval(context, {}, {'active_id' : active_id})
+        #domain=unsafe_eval(domain) # XXX need to test this line -> uid, active_id, active_ids, ...
 
         res = {
             'name': name,
@@ -617,7 +620,7 @@ form: module.record_id""" % (xml_id,)
         if rec_id:
             ids = [self.id_get(cr, rec_model, rec_id)]
         elif rec_src:
-            q = eval(rec_src, eval_dict)
+            q = unsafe_eval(rec_src, eval_dict)
             ids = self.pool.get(rec_model).search(cr, uid, q, context=context)
             if rec_src_count:
                 count = int(rec_src_count)
@@ -645,14 +648,14 @@ form: module.record_id""" % (xml_id,)
                     if key in brrec:
                         return brrec[key]
                     return dict.__getitem__(self2, key)
-            globals = d()
-            globals['floatEqual'] = self._assert_equals
-            globals['ref'] = ref
-            globals['_ref'] = ref
+            globals_dict = d()
+            globals_dict['floatEqual'] = self._assert_equals
+            globals_dict['ref'] = ref
+            globals_dict['_ref'] = ref
             for test in rec.findall('./test'):
                 f_expr = test.get("expr",'').encode('utf-8')
                 expected_value = _eval_xml(self, test, self.pool, cr, uid, self.idref, context=context) or True
-                expression_value = eval(f_expr, globals)
+                expression_value = unsafe_eval(f_expr, globals_dict)
                 if expression_value != expected_value: # assertion failed
                     self.assert_report.record_assertion(False, severity)
                     msg = 'assertion "%s" failed!\n'    \
@@ -702,7 +705,7 @@ form: module.record_id""" % (xml_id,)
                 return None
         res = {}
         for field in rec.findall('./field'):
-#TODO: most of this code is duplicated above (in _eval_xml)...
+            #TODO: most of this code is duplicated above (in _eval_xml)...
             f_name = field.get("name",'').encode('utf-8')
             f_ref = field.get("ref",'').encode('ascii')
             f_search = field.get("search",'').encode('utf-8')
@@ -713,7 +716,7 @@ form: module.record_id""" % (xml_id,)
             f_val = False
 
             if f_search:
-                q = eval(f_search, self.idref)
+                q = unsafe_eval(f_search, self.idref)
                 field = []
                 assert f_model, 'Define an attribute model="..." in your .XML file !'
                 f_obj = self.pool.get(f_model)
